==> haskell-ini-0.4.1-59-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ini.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 ini
version:              0.4.1
visibility:           public
id:                   ini-0.4.1-D0gqAEcVwWJ3vKqCZLUHUE
key:                  ini-0.4.1-D0gqAEcVwWJ3vKqCZLUHUE
license:              BSD-3-Clause
copyright:            2013 Chris Done
maintainer:           chrisdone@gmail.com
author:               Chris Done
homepage:             http://github.com/chrisdone/ini
synopsis:             Quick and easy configuration files in the INI format.
description:          Quick and easy configuration files in the INI format.
category:             Data, Configuration
abi:                  b0398039a0ee5574631fb6c8df8e5923
exposed:              True
exposed-modules:      Data.Ini
import-dirs:          /usr/lib/ghc-8.10.1/site-local/ini-0.4.1
library-dirs:         /usr/lib/ghc-8.10.1/site-local/ini-0.4.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/ini-0.4.1
hs-libraries:         HSini-0.4.1-D0gqAEcVwWJ3vKqCZLUHUE
depends:
    attoparsec-0.13.2.4-2hXHhVC1QQNJDYHhvxUfCW base-4.14.0.0
    text-1.2.3.2 unordered-containers-0.2.11.0-4xXgRDqRkAy1dBzEEXx9oz

haddock-interfaces:   /usr/share/doc/haskell-ini/html/ini.haddock
haddock-html:         /usr/share/doc/haskell-ini/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ini-0.4.1-63-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ini.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 ini
version:              0.4.1
visibility:           public
id:                   ini-0.4.1-EFKfNF401Q163F67aIYVcP
key:                  ini-0.4.1-EFKfNF401Q163F67aIYVcP
license:              BSD-3-Clause
copyright:            2013 Chris Done
maintainer:           chrisdone@gmail.com
author:               Chris Done
homepage:             http://github.com/chrisdone/ini
synopsis:             Quick and easy configuration files in the INI format.
description:          Quick and easy configuration files in the INI format.
category:             Data, Configuration
abi:                  fa06f4704e2238c005be5bbf46fae603
exposed:              True
exposed-modules:      Data.Ini
import-dirs:          /usr/lib/ghc-8.10.1/site-local/ini-0.4.1
library-dirs:         /usr/lib/ghc-8.10.1/site-local/ini-0.4.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/ini-0.4.1
hs-libraries:         HSini-0.4.1-EFKfNF401Q163F67aIYVcP
depends:
    attoparsec-0.13.2.4-2oqVeKJO3qZBCtXLlERv3x base-4.14.0.0
    text-1.2.3.2 unordered-containers-0.2.12.0-7yiTvjz2UcTGgWhTtgXiX9

haddock-interfaces:   /usr/share/doc/haskell-ini/html/ini.haddock
haddock-html:         /usr/share/doc/haskell-ini/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
